@@ -601,9 +601,15 @@ def columns_as_str(df, columns, uppercase=False, drop_empty=False, replace_na_va
     for c in columns:
         if c in df:
             if uppercase:    
-                df.loc[:,c] = df[c].astype(str, skipna=True).str.upper()
+                # pandas 0.25.0
+                #df.loc[:,c] = df[c].astype(str, skipna=True).str.upper()
+                # pandas 1.0.0
+                df.loc[:,c] = df[c].astype(str).str.upper()
             else:
-                df.loc[:,c] = df[c].astype(str, skipna=True)
+                # pandas 0.25.0
+                #df.loc[:,c] = df[c].astype(str, skipna=True)
+                # pandas 1.0.0
+                df.loc[:,c] = df[c].astype(str)
 
             if drop_empty:
                 df.loc[:,c].replace(to_replace='', value=np.nan, inplace=True)
@@ -674,7 +680,7 @@ def columns_as_float(df, columns, na_replace_value=None, drop_na=True):
             else:
                 df.loc[:,c].fillna(na_replace_value, inplace=True)
 
-            df.loc[:,c] = df[c].astype('float64', skipna=False)
+            df.loc[:,c] = df[c].astype('float64')
         else:
             if is_float_dtype(df[c]):
                 if drop_na:
@@ -711,7 +717,7 @@ def columns_as_int(df, columns, na_replace_value=None, drop_na=True):
     
     for c in columns:
         if c in df:
-            df.loc[:,c] = df[c].astype('int64', skipna=False)
+            df.loc[:,c] = df[c].astype('int64')
         else:
             print("Column '{}' doesn't exist.".format(c))
             
